@@ -2,7 +2,7 @@
 
 set -x
 
-exec 2>&1 > upgrade.log
+exec 2>&1 > update.log
 
 run() {
     pkgs=$1
