@@ -7,11 +7,15 @@ mydir=$(readlink -f $(dirname $BASH_SOURCE))
 export XC_WORKDIR=$(readlink -f $mydir/..)
 
 # Config variables
-program=main-ism330dhcx.sh
+program=icm20640-fifo-mp
 
 # Config from file
 source $mydir/../etc/sensorsettings.conf
 
+if [[ -z "$program" ]]; then
+    program=icm20640-fifo-mp
+fi
+
 umprog=$program
 
 pidfile=$XC_WORKDIR/measurement.pid
