@@ -73,7 +73,7 @@ meas.doUpdateControls1 = function() {
     var dispSelectButtons = ''
     var pinds = meas.headerInfo.pi.slice(1)
     var plainItemNames = pinds.map((k) => meas.headerInfo.names[k])
-    var dispItemNames = plainItemNames.map((k) => meas.translateMeasName(k))
+    var dispItemNames = plainItemNames.map((k) => meas.translateMeasName(k).replace('_', ' '))
     var grtempcols = 'auto'
     dispSelectButtons += '<button onclick="meas.loadDiagramNew(\'' + plainItemNames.join(',') + '\')"><span>'
 	+ dispItemNames.join('</span> / <span>') + '</span></button>'
@@ -397,9 +397,6 @@ meas.mk3plotsNew = function(data, time, names, units) {
 	var cid = 'container_' + (Number(k)+1)
 	var pelem = document.querySelector('#' + cid)
 	var pfun = Plotly.newPlot
-	if (pelem.data != undefined) {
-	    pfun = Plotly.react
-	}
 	var shapes = []
 	var border = meas.borders[names[k]]
 	var colors = [ blue_semi, cyan_semi, green_semi, orange_semi, red_semi ]
@@ -466,7 +463,7 @@ meas.mk3plotsNew = function(data, time, names, units) {
 		type: 'date',
 	    },
 	    yaxis: {
-		title: meas.translateMeasName(names[k]) + ' ' + units[k],
+		title: meas.translateMeasName(names[k]).replace('_', ' ') + ' ' + units[k],
 	    },
 	    shapes: shapes
 	}
@@ -980,12 +977,16 @@ meas.psLatestMeasurements = function(text) {
 		s.max += v.max*v.max
 		border = meas.borders[meas.headerInfo.names[vi]]
 		if (border) {
-		    atypes.push(Math.abs(meas.findinttr(border.intervals, v) - 2))
+		    atypes.push(meas.findinttr(border.intervals, v) - 2)
 		} else {
 		    atypes.push(0)
 		}
 	    }
-	    var a = Math.max(...atypes)
+	    var amax = Math.max(...atypes)
+	    var amin = Math.min(...atypes)
+	    var a = amin
+	    if (amax > -amin)
+		a = amax
 	    classes.push(meas.inttype(a+2))
 
 	    s.min = Math.sqrt(s.min).toPrecision(16)
@@ -1078,20 +1079,23 @@ meas.psLatestMeasurements = function(text) {
 	var item  = formattedValues[k]
 	var nitem = values[k]
 	var range = ranges[k]
-	var s = '<div><div class="value-range">' +
-	    '<div class="min-value">' + item.mind + '</div>' +
-	    ' <div class="mean-value">' + item.mean + '</div> ' +
-	    '<div class="max-value">' + item.maxd + '</div>' +
-	    '</div>'
-	if (range > 0) {
-	    var wperc = (100 * nitem.range / range), wcol = 'grey'
-	    if (wperc > 100) {
-		wperc = 100
-		wcol = 'red'
+	var s = '<div>'
+	if (nitem.mind != 0 || nitem.maxd != 0) {
+	    s = '<div class="value-range">' +
+		'<div class="min-value">' + item.mind + '</div>' +
+		' <div class="mean-value">' + item.mean + '</div> ' +
+		'<div class="max-value">' + item.maxd + '</div>' +
+		'</div>'
+	    if (range > 0) {
+		var wperc = (100 * nitem.range / range), wcol = 'grey'
+		if (wperc > 100) {
+		    wperc = 100
+		    wcol = 'red'
+		}
+		s += '<div class="mv-bar" style="width: ' + wperc + '%; background: ' + wcol + '">&nbsp;</div>'
 	    }
-	    s += '</div><div class="mv-bar" style="width: ' + wperc + '%; background: ' + wcol + '">&nbsp;</div>'
 	} else {
-	    s += '</div>'
+	    s = '<div class="value">' + item.mean + '</div>'
 	}
 	return s
     })
@@ -1117,7 +1121,8 @@ meas.psLatestMeasurements = function(text) {
 	    var axi = e.inds.indexOf(i)
 	    var html = ''
 	    if (axi == 0) {
-		html = '<div style="grid-column: 1/4;" class="livevalue-header"><span class="lv-head">' + e.name + ' ' + e.unit + '</span></div>'
+		html = '<div style="grid-column: 1/4;" class="livevalue-header"><span class="lv-head">' +
+		    meas.translateMeasName(e.name) + ' ' + e.unit + '</span></div>'
 	    }
 	    var axes = ['X', 'Y', 'Z']
 	    var ax = axes[axi]
@@ -1125,8 +1130,14 @@ meas.psLatestMeasurements = function(text) {
 		'<span class="lv-head">' + ax + '</span><br/><div class="lv-value">' + tds[i] + '</div></div>'
 	    tds[i] = html
 	} else {
-	    tds[i] = '<div title="' + title + '" style="grid-column: ' + col + ';" class="livevalue ' + classes[i] + '">' +
+	    var html = ''
+	    if (mode != 'aggr' && i > 0) {
+		html += '<div style="grid-column: 1/4;" class="livevalue-header"><span class="lv-head">' +
+		    tl.transl('Single values') + '</span></div>'
+	    }
+	    html += '<div title="' + title + '" style="grid-column: ' + col + ';" class="livevalue ' + classes[i] + '">' +
 		'<span class="lv-head">' + head + '</span><br/><div class="lv-value">' + tds[i] + '</div></div>'
+	    tds[i] = html
 	}
     })
 
@@ -1165,9 +1176,6 @@ meas.psLatestMeasurements = function(text) {
 	    meas.show('#' + cid)
 	    var pelem = document.querySelector('#' + cid)
 	    var pfun = Plotly.newPlot
-	    if (pelem.data != undefined) {
-		pfun = Plotly.react
-	    }
 	    var amax = Math.max(Math.abs(xval), Math.abs(yval), Math.abs(zval))
 	    meas.plott0[cid] = (new Date()).getTime()
 	    if (pelem.dataset.hold != 'true') {
@@ -1287,7 +1295,7 @@ meas.psLimitSelector = function(data, el) {
     var opts = Object.keys(meas.headerInfo.names).map((k) => {
 	var name = meas.headerInfo.names[k]
 	var unit = meas.headerInfo.units[k]
-	return '<option value="' + name + '">' + meas.translateMeasName(name) + '</option>'
+	return '<option value="' + name + '">' + meas.translateMeasName(name).replace('_', ' ') + '</option>'
     })
     text += opts.slice(1).join('')
     text += '</select>'
@@ -1405,6 +1413,7 @@ tl.apptable({
     shd2:  {de: 'uSense neu starten', en: 'Restart uSense'},
     shd3:  {de: 'WiFi neu starten', en: 'Restart WiFi'},
     shd4:  {de: 'Test-E-Mail senden', en: 'Send test email'},
+    shd5:  {de: 'Test-E-Mail', en: 'Test Email'},
     mor: {de: 'Mehr', en: 'More'},
 
     mar: {de: 'Messarchiv', en: 'Measurements Archive'},
@@ -1450,7 +1459,8 @@ tl.apptable({
     st1: {de: 'Sensoren', en: 'Sensors'},
     st2: {de: 'Gas- und Partikelsensoren', en: 'Gas and particles sensor'},
     st3: {de: 'Magnetometer', en: 'Magnetometer'},
-    st4: {de: 'Beschleuningssensor und Gyroskop', en: 'Accelerometer and Gyroscope'},
+    st4: {de: 'Beschleunigungssensor und Gyroskop', en: 'Accelerometer and Gyroscope'},
+    st4a: {de: 'Beschleunigungssensor', en: 'Accelerometer'},
     st5: {de: 'Temperatur-, Druck- und Feuchtigkeitssensoren', en: 'Temperature, pressure and humidity sensors'},
     st6: {de: 'Messprogramm', en: 'Measurement program'},
     st7: {de: 'Messinterval', en: 'Measurement interval'},
@@ -1480,17 +1490,25 @@ tl.apptable({
     uuc1: {de: 'Aktualisierungssteuerung', en: 'Update Control'},
     uuc2: {de: 'Aktualisiere Paketlisten', en: 'Scan for Updates'},
     uuc3: {de: 'Aktualisiere uSense Pakete', en: 'Update uSense packages'},
-    uuc4: {de: 'Aktualisiere Systempakate', en: 'Update system packages'},
+    uuc4: {de: 'Aktualisiere Systempakete', en: 'Update system packages'},
     uuc5: {de: 'Aktualisiere uSense Paketeliste', en: 'Scan for updates of uSense packages'},
     uuc6: {de: 'Aktualisiere Systempaketliste', en: 'Scan for updates of system packages'},
+    uuc6a: {de: 'Gerätesteuerung', en: 'Device Control'},
     uuc7: {de: 'Logdatei', en: 'Log file'},
     uuc8: {de: 'Tabelle', en: 'Table'},
+    uuc9: {de: 'uSense Pakete', en: 'uSense Packages'},
+    uuc10: {de: 'Aktualisierbare Systempakete', en: 'Upgradable System Packages'},
+    uuc11: {de: 'Datei', en: 'File'},
+    uuc12: {de: 'Anzeigen', en: 'Show'},
+    uuc13: {de: 'Aktualisieren', en: 'Upgrade'},
 
     stn1: {de: 'Messfrequenz', en: 'Sample rate'},
     stn2: {de: 'Messbereich', en: 'Measurement range'},
     stn3: {de: 'Einheit', en: 'Unit'},
     stn4: {de: 'Filter', en: 'Filter'},
-    stn5: {de: 'Bandbreite', en: 'Band width'},
+    stn5: {de: 'Tiefpass-Filter', en: 'Low Pass Filter'},
+    stn6: {de: 'Bandbreite', en: 'Band width'},
+    stn7: {de: 'Einzelwerte', en: 'Single values'},
 
     btn1: {de: 'Speichern', en: 'Save'},
 })
